#
# spec file for package cppcheck
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           cppcheck
Version:        1.63
Release:        0
License:        GPL-3.0+
Summary:        A tool for static C/C++ code analysis
Url:            http://cppcheck.sourceforge.net/
Group:          Development/Languages/C and C++
Source:         http://downloads.sourceforge.net/cppcheck/cppcheck-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gcc-c++
BuildRequires:  pcre-devel
BuildRequires:  python
BuildRequires:  xsltproc
Requires:       python
Requires:       python-Pygments
Requires:       python-xml

%description
This program tries to detect bugs that your C/C++ compiler don't see. Cppcheck
is versatile. You can check non-standard code that includes various compiler
extensions, inline assembly code, etc. Checking covers for example these
errors:

 * Out of bounds
 * Uninitialized member variable 'classname::varname'
 * Using 'memfunc' on class
 * Using 'memfunc' on struct that contains a 'std::classname'
 * Class Base which is inherited by class Derived does not have a virtual
   destructor
 * Memory leak: varname
 * Resource leak: varname
 * Deallocating a deallocated pointer: varname
 * Using 'varname' after it is deallocated / released
 * Invalid radix in call to strtol or strtoul. Must be 0 or 2-36
 * Overlapping data buffer varname
 * Unsigned division. The result will be wrong.
 * Unusual pointer arithmetic

%package gui
Summary:        A tool for static C/C++ code analysis
Group:          Development/Languages/C and C++
BuildRequires:  libqt4-devel >= 4.8.0
Requires:       cppcheck

%description gui

This is the gui for Cppcheck, a program to detect bugs that your C/C++ compiler
doesn't see.

%prep
%setup -q

%build
make %{?_smp_mflags} \
    CXXFLAGS="-DNDEBUG %{optflags}" \
    SRCDIR=build \
    CFGDIR=%{_datadir}/%{name} \
    HAVE_RULES=yes

pushd gui
qmake \
    QMAKE_CXXFLAGS="-DNDEBUG %{optflags}" \
    HAVE_RULES=yes
make %{?_smp_mflags}
popd

make man \
    DB2MAN=%{_datadir}/xml/docbook/stylesheet/nwalsh/current/manpages/docbook.xsl

%check
make %{?_smp_mflags} test \
    CXXFLAGS="-DNDEBUG %{optflags}" \
    HAVE_RULES=yes

%install
install -m 0755 -D cppcheck %{buildroot}%{_bindir}/cppcheck
install -m 0755 -D htmlreport/cppcheck-htmlreport %{buildroot}%{_bindir}/cppcheck-htmlreport
install -m 0755 -D gui/cppcheck-gui %{buildroot}%{_bindir}/cppcheck-gui
install -m 0644 -D cppcheck.1 %{buildroot}%{_mandir}/man1/cppcheck.1
install -d %{buildroot}%{_datadir}/%{name}
install -m 0644 cfg/*.cfg %{buildroot}%{_datadir}/%{name}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING
%{_bindir}/cppcheck
%{_bindir}/cppcheck-htmlreport
%{_datadir}/%{name}/
%{_mandir}/man1/cppcheck.1*

%files gui
%defattr(-,root,root)
%{_bindir}/cppcheck-gui

%changelog
